using System;
using System.Web;
using System.Xml;
using System.Web.UI.WebControls;

public partial class _Default : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!IsPostBack)
        {
            CreateTOC();
        }
    }

    /// <summary>
    /// Displays the HTML page in a iFrame.
    /// </summary>
    /// <param name="url">The URL.</param>
    private void DisplayHtmlPageInIFrame(string url)
    {
        //Display page in a iframe
        iFrame.Text = string.Format("<iframe id='iFrame' frameborder='0' src='{0}'>>This page uses an IFRAME but your browser does not support it.</iframe>", url); ;
    }

    /// <summary>
    /// Creates the TOC sync.
    /// </summary>
    private void CreateTOC()
    {
        string tocPath = Server.MapPath("WebTOC.xml");
        GenerateTOC(tocPath);
    }

    /// <summary>
    /// Generates and populates the TOC.
    /// </summary>
    /// <param name="tocPath">The toc path.</param>
    private void GenerateTOC(string tocPath)
    {
        //Load TOC
        XmlDocument toc = new XmlDocument();
        toc.Load(tocPath);

        //Find out root information
        XmlNode rootNode = toc.SelectSingleNode("//HelpTOCNode");
        string rootTitle = rootNode.Attributes["Title"].Value;
        string rootUrl = rootNode.Attributes["Url"].Value;

        //Set information on page
        Page.Title = rootTitle;
        DisplayHtmlPageInIFrame(rootUrl);

        //Setup Root Tree Node
        tocTree.Nodes.Clear();
        TreeNode tNode = new TreeNode(rootTitle, rootUrl);
        tocTree.Nodes.Add(tNode);

        //Start recursive call
        AddNode(rootNode, tNode);

        tocTree.ExpandAll();
    }

    /// <summary>
    /// Adds the node to the parentTreeNode
    /// </summary>
    /// <param name="xmlNode">The XML node.</param>
    /// <param name="parentTreeNode">The parent tree node.</param>
    private void AddNode(XmlNode xmlNode, TreeNode parentTreeNode)
    {
        //Check to see if it has any Child Nodes
        if (xmlNode.HasChildNodes)
        {
            foreach (XmlNode node in xmlNode.ChildNodes)
            {
                string title = node.Attributes["Title"].Value;

                string url;
                if (node.Attributes["Url"] == null)
                    url = "#";
                else
                    url = node.Attributes["Url"].Value;


                //Create node for tree
                TreeNode newNode = new TreeNode(HttpUtility.HtmlEncode(title), url);

                //Add node to parent tree node
                parentTreeNode.ChildNodes.Add(newNode);

                //Call method again for possible child methods
                AddNode(node, newNode);
            }
        }
    }

    /// <summary>
    /// Handles the SelectedNodeChanged event of the tocTree control.
    /// </summary>
    /// <param name="sender">The source of the event.</param>
    /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
    protected void tocTree_SelectedNodeChanged(object sender, EventArgs e)
    {
        //Display selected node's page
        DisplayHtmlPageInIFrame(tocTree.SelectedNode.Value);
    }

    protected void ExpandAll_Click(object sender, System.Web.UI.ImageClickEventArgs e)
    {
        tocTree.ExpandAll();
    }

    protected void CollapseAll_Click(object sender, System.Web.UI.ImageClickEventArgs e)
    {
        tocTree.CollapseAll();
    }
}